@@ -1,11 +1,10 @@
 
 __title__ = 'fastposter'
 __description__ = 'Python client for fastposter cloud.'
-__url__ = 'https://cloud.fastposter.net/'
-__version__ = '1.1.2'
-# __build__ = 0x022300
+__url__ = 'https://cloud.fastposter.net/doc/'
+__version__ = '1.1.8'
 __author__ = 'Alex'
 __author_email__ = 'service@fastposter.net'
-__license__ = 'MIT 2.0'
+__license__ = 'MIT'
 __copyright__ = 'Copyright 2023 fastposter.net'
 
